# Perform optional tests
%bcond_without  perl_Syntax_Operator_Divides_enables_optional_test

# A build cycle: perl-Syntax-Operator-Divides → perl-Syntax-Keyword-Match.spec
%if %{with perl_Syntax_Operator_Divides_enables_optional_test} && !%{defined perl_bootstrap}
%global optional_tests 1
%else
%global optional_tests 0
%endif

Name:           perl-Syntax-Operator-Divides
Version:        0.08
Release:        1%{?dist}
Summary:        Infix operator for division test
License:        GPL-1.0-or-later OR Artistic-1.0-Perl
URL:            https://metacpan.org/release/Syntax-Operator-Divides
Source0:        https://cpan.metacpan.org/authors/id/P/PE/PEVANS/Syntax-Operator-Divides-%{version}.tar.gz
BuildRequires:  coreutils
BuildRequires:  findutils
BuildRequires:  perl-devel
BuildRequires:  perl-generators
BuildRequires:  perl-interpreter
# Version from Build.PL for pad_alloc() used in Divides.xs
BuildRequires:  perl(:VERSION) >= 5.16
BuildRequires:  perl(ExtUtils::CBuilder)
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(strict)
BuildRequires:  perl(warnings)
%global xs_parse_infix_minver 0.43
BuildRequires:  perl(XS::Parse::Infix::Builder) >= %{xs_parse_infix_minver}
# Run-time:
BuildRequires:  perl(Carp)
%global meta_min_ver 0.003.002
BuildRequires:  perl(meta) >= %{meta_min_ver}
BuildRequires:  perl(XSLoader)
# Tests:
BuildRequires:  perl(Test2::V0)
%if %{optional_tests}
# Optional tests:
BuildRequires:  perl(Syntax::Keyword::Match) >= 0.08
BuildRequires:  perl(Test::Pod) >= 1.00
%endif
Requires:       perl(meta) >= %{meta_min_ver}
# Minimal XS::Parse::Infix version requested in boot_xs_parse_infix() argument
Requires:       perl(XS::Parse::Infix) >= %{xs_parse_infix_minver}
%if %{defined perl_XS_Parse_Infix_ABI}
# XS::Parse::Infix ABI checked in XSParseInfix.h generated by
# XS::Parse::Infix::Builder. 
Requires:       %{perl_XS_Parse_Infix_ABI}
%endif

# Remove underspecified dependencies
%global __requires_exclude %{?__requires_exclude:%{__requires_exclude}|}^perl\\(meta\\) >= 0.003$

%description
This module provides an infix operator that implements an integer divides
test which returns true if the lefthand operand is a whole multiple of the
righthand.

%package tests
Summary:        Tests for %{name}
BuildArch:      noarch
Requires:       %{name} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires:       perl-Test-Harness
%if %{optional_tests}
Requires:       perl(Syntax::Keyword::Match) >= 0.08
%endif

%description tests
Tests from %{name}. Execute them
with "%{_libexecdir}/%{name}/test".

%prep
%setup -q -n Syntax-Operator-Divides-%{version}
%if !%{optional_tests}
for T in t/80match-divides.t t/99pod.t; do
    rm "$T"
    perl -i -ne 'print $_ unless m{^\Q'"$T"'\E}' MANIFEST
done
%endif
chmod +x t/*.t

%build
perl Build.PL --installdirs=vendor --optimize="$RPM_OPT_FLAGS"
./Build

%install
./Build install --destdir=%{buildroot} --create_packlist=0
find %{buildroot} -type f -name '*.bs' -size 0 -delete
%{_fixperms} %{buildroot}/*
# Install tests
mkdir -p %{buildroot}%{_libexecdir}/%{name}
cp -a t %{buildroot}%{_libexecdir}/%{name}
%if %{optional_tests}
rm %{buildroot}%{_libexecdir}/%{name}/t/99pod.t
%endif
cat > %{buildroot}%{_libexecdir}/%{name}/test << 'EOF'
#!/bin/sh
cd %{_libexecdir}/%{name} && exec prove -I . -j "$(getconf _NPROCESSORS_ONLN)"
EOF
chmod +x %{buildroot}%{_libexecdir}/%{name}/test

%check
export HARNESS_OPTIONS=j$(perl -e 'if ($ARGV[0] =~ /.*-j([0-9][0-9]*).*/) {print $1} else {print 1}' -- '%{?_smp_mflags}')
./Build test

%files
%license LICENSE
%doc Changes README
%dir %{perl_vendorarch}/auto/Syntax
%dir %{perl_vendorarch}/auto/Syntax/Operator
%{perl_vendorarch}/auto/Syntax/Operator/Divides
%dir %{perl_vendorarch}/Syntax
%dir %{perl_vendorarch}/Syntax/Operator
%{perl_vendorarch}/Syntax/Operator/Divides.pm
%{_mandir}/man3/Syntax::Operator::Divides.*

%files tests
%{_libexecdir}/%{name}

%changelog
* Wed Jul 24 2024 Petr Pisar <ppisar@redhat.com> - 0.08-1
- 0.08 bump

* Fri Jul 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.07-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Wed Jun 12 2024 Jitka Plesnikova <jplesnik@redhat.com> - 0.07-3
- Perl 5.40 re-rebuild of bootstrapped packages

* Tue Jun 11 2024 Jitka Plesnikova <jplesnik@redhat.com> - 0.07-2
- Perl 5.40 rebuild

* Wed Feb 14 2024 Petr Pisar <ppisar@redhat.com> - 0.07-1
- 0.07 bump

* Thu Jan 25 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.04-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Jan 21 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.04-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Wed Jul 26 2023 Petr Pisar <ppisar@redhat.com> - 0.04-1
- 0.04 bump

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.03-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Wed Jul 12 2023 Jitka Plesnikova <jplesnik@redhat.com> - 0.03-4
- Perl 5.38 re-rebuild of bootstrapped packages

* Tue Jul 11 2023 Jitka Plesnikova <jplesnik@redhat.com> - 0.03-3
- Perl 5.38 rebuild

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.03-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Thu Jan 05 2023 Petr Pisar <ppisar@redhat.com> - 0.03-1
- 0.03 bump

* Tue Oct 25 2022 Petr Pisar <ppisar@redhat.com> - 0.02-1
- 0.02 bump

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.01-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Fri Jun 03 2022 Jitka Plesnikova <jplesnik@redhat.com> - 0.01-5
- Perl 5.36 re-rebuild of bootstrapped packages

* Tue May 31 2022 Jitka Plesnikova <jplesnik@redhat.com> - 0.01-4
- Perl 5.36 rebuild

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.01-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Nov 12 2021 Petr Pisar <ppisar@redhat.com> - 0.01-2
- Finish bootstrap (bug #2017689)

* Wed Oct 27 2021 Petr Pisar <ppisar@redhat.com> 0.01-1
- Specfile autogenerated by cpanspec 1.78.
